# Changelog

## 0.1.0 (2025-09-18)


### Features

* rename srpc python import to slimrpc ([#660](https://github.com/agntcy/slim/issues/660)) ([d7ed9b2](https://github.com/agntcy/slim/commit/d7ed9b206c49096628541404766790c6a2406d7e))
* **slimrpc:** separate Channel and ChannelFactory ([#685](https://github.com/agntcy/slim/issues/685)) ([3dc8a5b](https://github.com/agntcy/slim/commit/3dc8a5b8a434180a275fcbce5f26b62b3739b4c9))
* **slimrpc:** Support existing slim binding in ChannelFactory ([#690](https://github.com/agntcy/slim/issues/690)) ([d7093b7](https://github.com/agntcy/slim/commit/d7093b7b022e5fc707ecef61953e6016f05e4a73))
* update version of slima2a and slimrpc wheels ([#637](https://github.com/agntcy/slim/issues/637)) ([e6569cb](https://github.com/agntcy/slim/commit/e6569cba88afff65b7a736f7511d9ea2a57f7dc2))


### Bug Fixes

* **slima2a, slimrpc:** make mypy happy ([#671](https://github.com/agntcy/slim/issues/671)) ([5ab4628](https://github.com/agntcy/slim/commit/5ab462854c57a4788cc5eec8eecc734ab34cb2d5))
